@@ -248,10 +248,14 @@ class WechatySchedulerMixin:
         trigger = CronTrigger(
             hour=hour
         )
+        job = self.scheduler.get_job(job_id=job_id)
+        if job is not None:
+            self.scheduler.remove_job(job_id=job_id)
 
         self.scheduler.add_job(
             func=handler,
             trigger=trigger,
+            id=job_id,
             args=args,
             kwargs=kwargs
         )
@@ -273,6 +277,10 @@ class WechatySchedulerMixin:
 
         job_id = str(job_id)
 
+        job = self.scheduler.get_job(job_id=job_id)
+        if job is not None:
+            self.scheduler.remove_job(job_id=job_id)
+
         trigger = IntervalTrigger(
             minutes=minutes
         )
